#!/usr/bin/python
# J_waveform_envelope_F0.py
# Requires file module_fm_demodulation.py

import sys, re
import numpy as np
import matplotlib.pyplot as plt
import matplotlib
import scipy.io.wavfile as wave
from scipy.signal import butter, lfilter, medfilt
from module_fm_demodulation import *

figwidth = 8
figheight = 6

#-------------------------------------------------------------------------------

if len(sys.argv) > 1:
	wavfilename = sys.argv[1]						# get input filename from command line 
else:
	wavfilename = "DATA/one-to-ten-Putonghua-Lara-16k-mono.wav"

fs, signal = wave.read(wavfilename)							# read sampling frequency and signal
wavfilebase = re.sub("^.*/","",wavfilename)
wavfilebase = re.sub("-16k-mono","",wavfilebase[:-4])
figurefilename = "PNG/J_%s.png"%wavfilebase

signallength = len(signal)									# define signal length in bytes
signalseconds = signallength / fs							# define signal length in seconds
signal = signal / max(abs(signal))							# normalise signal -1 ... 0 ... 1

b, a = butter(5, 5 / (0.5 * fs), btype="low")				# define Butterworth filter
envelope = lfilter(b, a, abs(signal))						# apply filter to create lf envelope
envelope = envelope / max(envelope)							# normalise envelope 0 ... 1

f0array, framerate = f0estimate(signal, fs)
f0arraylength = len(f0array)

#-------------------------------------------------------------------------------

fig, (plt01, plt02, plt03) = plt.subplots(nrows=3, ncols=1, figsize=(figwidth, figheight))
plt.suptitle = "%s [file: %s]"%("Speech signal demodulation", wavfilebase)

xaxistime = np.linspace(0, signalseconds, signallength)	# define x axis in seconds
plt01.plot(xaxistime, envelope, color="red")
plt01.set_xlabel("Time")
plt01.set_ylabel("Amplitude")
plt01.set_xlim(0, np.ceil(signalseconds))

xaxistime = np.linspace(0, signalseconds, signallength)	# define x axis in seconds
plt02.plot(xaxistime, signal, color="lightgrey")		# plot waveform in grey
plt02.set_xlabel("Time")
plt02.set_ylabel("Amplitude")
plt02.set_xlim(0, np.ceil(signalseconds))

xaxistime = np.linspace(0, signalseconds, f0arraylength)	# define x axis in seconds
plt03.scatter(xaxistime, f0array, s=1, color="blue")		# plot waveform in grey
plt03.set_ylim(f0min, f0max)
plt03.set_xlabel("Time")
plt03.set_ylabel("Frequency")
plt03.set_xlim(0, np.ceil(signalseconds))

# plt.tight_layout(pad=1, w_pad=0, h_pad=5)
plt.tight_layout(pad=1, w_pad=0, h_pad=0)
plt.savefig(figurefilename)
plt.show()

